@@ -1,13 +1,13 @@
 #!/bin/sh
 # Check whether a PR has been analyzed within the acknowledgment period.
-# Copyright (C) 1993, 1994, 1995, 1999, 2002 Free Software Foundation, Inc.
+# Copyright (C) 1993,94,95,99,2002,07 Free Software Foundation, Inc.
 # Contributed by Brendan Kehoe (brendan@cygnus.com).
 #
 # This file is part of GNU GNATS.
 #
 # GNU GNATS is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2, or (at your option)
+# the Free Software Foundation; either version 3, or (at your option)
 # any later version.
 #
 # GNU GNATS is distributed in the hope that it will be useful,
@@ -16,8 +16,8 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with GNU GNATS; see the file COPYING.  If not, write to
-# the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+# along with GNU GNATS; see the file COPYING. If not, see
+# <http://www.gnu.org/licenses/>.
 
 prog=at-pr
 USAGE="Usage: $prog [-h|--help] [-d|--database database_name] arguments
@@ -32,7 +32,10 @@ USAGE="Usage: $prog [-h|--help] [-d|--database database_name] arguments
  6 - address for GNATS_ADMIN
 "
 
-PATH=/bin:/usr/bin; export PATH
+PATH="@pkglibexecdir@:@sbindir@:@bindir@:/bin:/usr/bin:${PATH}"
+export PATH
+
+QUERY_PR="query-pr"
 
 if [ $# -eq 0 ]
 then
@@ -66,9 +69,8 @@ while [ $# -gt 6 ]; do
 done
 
 export GNATSDB
-VERSION=xVERSIONx
-LIBEXECDIR="xLIBEXECDIRx/gnats"
-QUERY_PR="xBINDIRx/query-pr"
+VERSION=@VERSION@
+
 
 eval `$QUERY_PR --print-sh-vars`
 
@@ -115,7 +117,7 @@ Subject: mail output from at-pr
 fi
 
 if [ "$STATE" = "${DEFAULTSTATE}" ]; then
-  $LIBEXECDIR/mail-agent << __EOF__
+    mail-agent << __EOF__
 ${STEALTH_HEADER}From: $6 (GNATS Management)
 To: $5, $RESP_ADDR, $6
 Subject: PR $2 not analyzed in $1 hours
