@@ -1,5 +1,5 @@
 /* Common functions for each GNATS client.
-   Copyright (C) 1994, 1995, 1999, 2000, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1994, 1995, 1999, 2000, 2002, 2007 Free Software Foundation, Inc.
    Copyright (C) 2001 Dan Martinez
    Contributed by Brendan Kehoe (brendan@cygnus.com).
 
@@ -7,7 +7,7 @@ This file is part of GNU GNATS.
 
 GNU GNATS is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU GNATS is distributed in the hope that it will be useful,
@@ -16,8 +16,9 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more detailmails.
 
 You should have received a copy of the GNU General Public License
-along with GNU GNATS; see the file COPYING.  If not, write to the Free
-Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
+along with GNU GNATS; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
+*/
 
 #include "gnats.h"
 #include "gnatsd.h"
@@ -481,6 +482,8 @@ static int
 clientConnect (ErrorDesc *err, const char *hostname, int port)
 {
   FILE *file;
+  struct hostent *host;
+  struct sockaddr_in server;
 
 #if 1
   if (hostname[0] == '/' || hostname[0] == '.')
@@ -510,9 +513,6 @@ clientConnect (ErrorDesc *err, const char *hostname, int port)
   else
 #endif
     {
-      struct sockaddr_in server;
-      struct hostent *host;
-
       memset ((char *) &server, 0, sizeof (server));
       server.sin_family = AF_INET;
       if (isdigit ((int) hostname[0]))
