@@ -1,5 +1,5 @@
 /* Commands for the GNATS server.
-   Copyright (C) 1994, 95, 95, 1997, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1994, 95, 95, 1997, 2001, 2002, 2007 Free Software Foundation, Inc.
    Contributed by Brendan Kehoe (brendan@cygnus.com).
    Further hacked by Milan Zamazal (pdm@zamazal.org) and other contributors.
 
@@ -7,7 +7,7 @@ This file is part of GNU GNATS.
 
 GNU GNATS is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU GNATS is distributed in the hope that it will be useful,
@@ -16,13 +16,15 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more detailmails.
 
 You should have received a copy of the GNU General Public License
-along with GNU GNATS; see the file COPYING.  If not, write to the Free
-Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
+along with GNU GNATS; see the file COPYING.  If not,  see
+<http://www.gnu.org/licenses/>.
+*/
 
 #include "gnats.h"
 #include "gnatsd.h"
 #include "query.h"
 #include "mail.h"
+#include "ds.h"
 
 #ifdef HAVE_KERBEROS
 #include <des.h>
@@ -365,7 +367,7 @@ set_confidential_access (QueryExpr *search)
     {
       QueryExpr newQ
 	= parseQueryExpression (currentDatabase, 
-				"builtinfield:Confidential ~ \"no\"",
+				"builtinfield:Confidential~\"no\"",
 				NULL);
       *search = booleanQuery (QueryAnd, *search, newQ);
     }
@@ -381,8 +383,8 @@ do_server_query (int ac, char **av)
       return;
     }
   set_confidential_access (&query);
-  if (iterate_prs (currentDatabase, ac, av, query, queryFormat, 
-		   server_print_query, &err) < 0)
+  if (db_query (currentDatabase, ac, av, query,
+		server_print_query, queryFormat, &err) < 0)
     {
       print_server_errors (err);
     }
@@ -415,7 +417,7 @@ GNATS_lock (int ac, char **av)
       return;
     }
 
-  if (! prExists (currentDatabase, av[0], &err))
+  if (! pr_exists (currentDatabase, av[0], &err))
     {
       print_server_errors (err);
       return;
@@ -440,7 +442,7 @@ GNATS_lock (int ac, char **av)
 
   if ((result = lock_pr (currentDatabase, av[0], av[1], l, &err)) != 0)
     {
-      PR *pr = readPRWithNum (currentDatabase, av[0], 0, &err);
+      PR *pr = pr_load_by_id (currentDatabase, av[0], 0, &err);
       
       if (pr != NULL)
 	{
@@ -539,7 +541,7 @@ GNATS_unlk (int ac, char **av)
   if (! chk_nargs (ac, "PR to be unlocked"))
     return;
 
-  if (! prExists (currentDatabase, av[0], &err))
+  if (! pr_exists (currentDatabase, av[0], &err))
     {
       print_server_errors (err);
       return;
@@ -775,7 +777,7 @@ GNATS_edit (int ac, char **av)
   if (! chk_nargs (ac, "PR to be edited"))
     return;
 
-  if (! prExists (currentDatabase, av[0], &err))
+  if (! pr_exists (currentDatabase, av[0], &err))
     {
       print_server_errors (err);
       return;
@@ -1095,7 +1097,6 @@ GNATS_expr (int ac, char **av)
 void
 GNATS_rset (int ac, char **av ATTRIBUTE_UNUSED)
 {
-  int new_index = 0;
   ErrorDesc err = NULL;
 
   if (ac != 0)
@@ -1107,28 +1108,15 @@ GNATS_rset (int ac, char **av ATTRIBUTE_UNUSED)
   freeQueryExpr (query);
   query = NULL;
 
-  if (checkPRChain (currentDatabase, &err))
-    {
-      new_index = 1;
-    }
-
+  db_reset (currentDatabase, &err);
   if (err != NULL)
     {
       print_server_errors (err);
       freeDatabaseInfo (currentDatabase);
       currentDatabase = NULL;
+      return;
     }
-  else
-    {
-      if (new_index)
-	{
-	  printf ("%d Reset state...reloaded the index.\r\n", CODE_OK);
-	}
-      else
-	{
-	  printf ("%d Reset state.\r\n", CODE_OK);
-	}
-    }
+  printf ("%d Reset state.\r\n", CODE_OK);
 }
 
 static char *
