@@ -6,7 +6,7 @@ This file is part of GNU GNATS.
 
 GNU GNATS is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU GNATS is distributed in the hope that it will be useful,
@@ -15,13 +15,15 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU GNATS; see the file COPYING.  If not, write to the Free
-Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
+along with GNU GNATS; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
+*/
 
 #include "gnats.h"
 #include "mail.h"
 #include "pcodes.h"
 #include "field.h"
+#include "ds.h"
 
 struct databaseInfo
 {
@@ -42,10 +44,10 @@ struct databaseInfo
   FieldList requiredInputFields;
   DatabaseFieldInfo fieldInfo;
   AdmEntry *hostList;
-  IndexDesc indexDesc;
   MailMessageFormat mailFormatList;
   InputTemplate *inputTemplate;
   FieldIndex builtinFields[NUM_BUILTIN_FIELDS];
+  void *ds_private;    /* all the datastore specific stuff */
   /* Next and previous entries in the chain.  */
   struct databaseInfo *next, *prev;
 };
@@ -87,9 +89,9 @@ newDatabaseInfo (void)
   res->requiredInputFields = NULL;
   res->fieldInfo = NULL;
   res->hostList = NULL;
-  res->indexDesc = NULL;
   res->mailFormatList = NULL;
   res->inputTemplate = NULL;
+  res->ds_private = NULL;
 
   for (x = 0; x < NUM_BUILTIN_FIELDS; x++)
     {
@@ -274,16 +276,6 @@ setRequiredInputFields (DatabaseInfo database, FieldList list)
     }
 }
 
-void
-setIndexDesc (DatabaseInfo database, IndexDesc new)
-{
-  if (databaseValid (database))
-    {
-      finishIndexDesc (database, new);
-      database->indexDesc = new;
-    }
-}
-
 void
 setInputTemplate (DatabaseInfo database, InputTemplate *list)
 {
@@ -316,6 +308,12 @@ setMailFormatList (DatabaseInfo database, MailMessageFormat formatList)
   database->mailFormatList = formatList;
 }
 
+void
+setDatastorePrivate(DatabaseInfo database, void *data)
+{
+  database->ds_private = data;
+}
+
 int
 keepReceivedHeaders (const DatabaseInfo database)
 {
@@ -583,6 +581,12 @@ getMailFormatList (const DatabaseInfo database)
   return database->mailFormatList;
 }
 
+void *
+getDatastorePrivate(const DatabaseInfo database)
+{
+  return database->ds_private;
+}
+
 static AdmEntry *dbList = NULL;
 
 static int
@@ -643,12 +647,22 @@ initDatabaseList (ErrorDesc *err)
 	  info = info->next;
 	}
     }
-  
-  if (readAdmFile (GLOBAL_DB_LIST_FILE, 3, &dbList, 1) < 0)
+
+  /* Ensure global_db_list_file points to something
+   *
+   * TODO: This should probably move to a global "set defaults"
+   * routine
+   **/
+#ifdef GLOBAL_DB_LIST_FILE
+  if (!global_db_list_file)
+    global_db_list_file = GLOBAL_DB_LIST_FILE;
+#endif
+
+  if (readAdmFile (global_db_list_file, 3, &dbList, 1) < 0)
     {
       setError (err, CODE_FILE_ERROR, 
 		"Unable to open global configuration file %s",
-		GLOBAL_DB_LIST_FILE);
+		global_db_list_file);
       dbList = NULL;
       return -1;
     }
@@ -656,7 +670,7 @@ initDatabaseList (ErrorDesc *err)
     {
       setError (err, CODE_FILE_ERROR,
 		"List of databases in %s is empty?!",
-		GLOBAL_DB_LIST_FILE);
+		global_db_list_file);
       return -1;
     }
   else
@@ -741,25 +755,17 @@ loadDatabase (const char *databaseName, AdmEntry *databaseEnt, ErrorDesc *err)
 	       res->databaseEnt->admFields[DatabaseListPath],
 	       databaseName);
       freeDatabaseInfo (res);
-      res = NULL;
+      return NULL;
     }
-  else
-    {
-      char *path;
 
-      initHostList (res);
-      path = gnats_adm_dir (res, "dbconfig");
-      if (fconfigParse (res, path, NULL, err))
-	{
-	  freeDatabaseInfo (res);
-	  res = NULL;
-	}
-      else
-	{
-	  initIndex (res);
-	}
-      free (path);
+  initHostList (res);
+
+  if (db_init (res, err) < 0)
+    {
+      freeDatabaseInfo (res);
+      return NULL;
     }
+
   return res;
 }
 
@@ -867,12 +873,6 @@ getRequiredInputFields (const DatabaseInfo database)
   return database->requiredInputFields;
 }
 
-IndexDesc
-getIndexDesc (const DatabaseInfo database)
-{
-  return database->indexDesc;
-}
-
 InputTemplate *
 getInputTemplate (const DatabaseInfo database)
 {
@@ -920,16 +920,6 @@ clearGlobalChangeActions (DatabaseInfo database)
   database->changeActions = NULL;
 }
 
-static void
-clearIndexDesc (DatabaseInfo database)
-{
-  if (database->indexDesc != NULL)
-    {
-      freeIndexDesc (database->indexDesc);
-      database->indexDesc = NULL;
-    }
-}
-
 static void
 clearQueryFormatList (DatabaseInfo database)
 {
@@ -965,11 +955,13 @@ freeDatabaseInfo (DatabaseInfo database)
 {
   if (database != NULL)
     {
-      clearPRChain (database);
       clearQueryFormatList (database);
-      clearFieldList (database);
       clearMessageFormatList (database);
-      clearIndexDesc (database);
+      if (database->ds_private != NULL)
+        {
+	  db_destroy (database);  /* free up the datastore specific stuff */
+        }
+      clearFieldList (database);
       clearAuditTrailFormat (database);
       clearHostList (database);
       clearInputTemplate (database);
