@@ -1,12 +1,12 @@
 /* Basic database info.
-   Copyright (C) 1999 Free Software Foundation, Inc.
+   Copyright (C) 1999,2007 Free Software Foundation, Inc.
    Contributed by Bob Manson <manson@juniper.net>.
 
 This file is part of GNU GNATS.
 
 GNU GNATS is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU GNATS is distributed in the hope that it will be useful,
@@ -15,8 +15,9 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU GNATS; see the file COPYING.  If not, write to the Free
-Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
+along with GNU GNATS; see the file COPYING. If not, see
+<http://www.gnu.org/licenses/>.
+*/
 
 #ifndef _DATABASE_H
 #define _DATABASE_H
@@ -102,8 +103,7 @@ extern void setBuiltinDBField (DatabaseInfo database, int whichField,
 extern void setMailFormatList (DatabaseInfo database,
 			       MailMessageFormat mailFormatList);
 extern void setRequiredInputFields (DatabaseInfo database, FieldList list);
-
-extern void setIndexDesc (DatabaseInfo database, const IndexDesc desc);
+extern void setDatastorePrivate(DatabaseInfo database, void *data);
 
 extern int keepReceivedHeaders (const DatabaseInfo database);
 extern int debugMode (DatabaseInfo database);
@@ -124,12 +124,12 @@ extern int createCategoryDirs (const DatabaseInfo database);
 QueryFormat *getAuditTrailFormat (const DatabaseInfo database);
 extern int categoryDirPerms (const DatabaseInfo database);
 extern FieldList getRequiredInputFields (const DatabaseInfo database);
-extern IndexDesc getIndexDesc (const DatabaseInfo database);
 extern InputTemplate *getInputTemplate (const DatabaseInfo database);
 extern QueryFormat *getQueryFormatList (const DatabaseInfo database);
 extern MailMessageFormat getMailFormatList (const DatabaseInfo database);
 extern FieldIndex getBuiltinField (const DatabaseInfo database,
 				   int whichField);
+extern void *getDatastorePrivate(const DatabaseInfo database);
 
 extern void freeDatabaseInfo (DatabaseInfo database);
 
