@@ -6,7 +6,7 @@ This file is part of GNU GNATS.
 
 GNU GNATS is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU GNATS is distributed in the hope that it will be useful,
@@ -15,14 +15,16 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU GNATS; see the file COPYING.  If not, write to the Free
-Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
+along with GNU GNATS; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
+*/
 
 #include "gnats.h"
 #include "gnatsd.h"
 #include "regex.h"
 #include "query.h"
 #include "mail.h"
+#include "ds.h"
 
 /* Euuugh.  There's gotta be a better way to keep this around.  */
 static char *newAuditTrailEntries = NULL;
@@ -134,79 +136,47 @@ applyChangeAction (ChangeActions action, PR *pr, PR *oldPR, FieldIndex field,
 }
 
 static int
-addAuditEntryP (const DatabaseInfo database, FieldIndex field,
-		ChangeActions actions)
-{
-  while (actions != NULL)
-    {
-      if (actions->addAuditTrail)
-	{
-	  return 1;
-	}
-      actions = actions->next;
-    }
-
-  if (fieldDefForIndex (field)->datatype != MultiText)
-    {
-      ChangeActions globalActions = globalChangeActions (database);
-
-      while (globalActions != NULL)
-	{
-	  if (globalActions->addAuditTrail)
-	    {
-	      return 1;
-	    }
-	  globalActions = globalActions->next;
-	}
-    }
-  return 0;
-}
-
-static int
-applyChangeActions (PR *pr, PR *oldPR, FieldIndex field, 
+applyChangeActions (PR *pr, PR *oldPR, FieldIndex field,
 		    ChangeActions actions, ErrorDesc *err,
 		    FormatNamedParameter *params)
 {
-  {
-    ChangeActions actionList = actions;
+  ChangeActions actionList = actions;
 
-    while (actionList != NULL)
-      {
-	if (actionList->expr == NULL
-	    || pr_matches_expr (pr, oldPR, actionList->expr, params))
-	  {
-	    if (applyChangeAction (actionList, pr, oldPR, field, err, params))
-	      {
-		return 1;
-	      }
-	  }
-	actionList = actionList->next;
-      }
-  }
-
-  if (field != InvalidFieldIndex && addAuditEntryP (pr->database, 
-						    field, actions))
+  while (actionList != NULL)
     {
-      ChangeActions action = actions;
-      while (actions != NULL)
+      if (actionList->expr == NULL
+	    || pr_matches_expr (pr, oldPR, actionList->expr, params))
 	{
-	  if (actions->addAuditTrail)
+	  if (applyChangeAction (actionList, pr, oldPR, field, err, params))
 	    {
-	      break;
+	      return 1;
 	    }
-	  actions = actions->next;
-	}
 
-      if (action != NULL)
-	{
-	  addAuditTrailEnt (pr, action->auditTrailFormat, params, err);
-	}
-      else
-	{
-	  addAuditTrailEnt (pr, NULL, params, err);
+          if (field != InvalidFieldIndex && actionList->addAuditTrail)
+	    {
+	      addAuditTrailEnt (pr, actionList->auditTrailFormat, params, err);
+	    }
 	}
+      actionList = actionList->next;
     }
 
+  if (field != InvalidFieldIndex)
+    {
+      if (fieldDefForIndex (field)->datatype != MultiText)
+	{
+	  ChangeActions globalActions = globalChangeActions (pr->database);
+
+	  while (globalActions != NULL)
+	    {
+	      if (globalActions->addAuditTrail)
+		{
+		  addAuditTrailEnt (pr, globalActions->auditTrailFormat,
+				    params, err);
+		}
+	      globalActions = globalActions->next;
+	    }
+	}
+    }
   return 0;
 }
 
@@ -276,14 +246,6 @@ processPRChanges (const char *editUserEmailAddr, PR *old_pr, PR *new_pr,
   ChangeActions globalActions = globalChangeActions (database);
   int *fieldsChanged;
 
-  if (! PR_IS_FULL (old_pr))
-    {
-      if (fillInPR (old_pr, err) != 0)
-	{
-	  return 1;
-	}
-    }
-
   fieldsChanged = (int *) xmalloc (sizeof (int) * num_fields);
 
   for (x = 0; x < num_fields; x++)
@@ -401,13 +363,6 @@ static int
 rewrite_pr (PR *pr, PR *new_pr, const char *editUserEmailAddr, ErrorDesc *err)
 {
   const DatabaseInfo database = new_pr->database;
-  FILE *prfile;
-
-  char *new_path = NULL;
-  char *old_path = NULL;
-  char *bkup_path = NULL;
-
-  int res = 1;
 
   newAuditTrailEntries = NULL;
 
@@ -430,123 +385,11 @@ rewrite_pr (PR *pr, PR *new_pr, const char *editUserEmailAddr, ErrorDesc *err)
       return 0;
     }
 
-  /* check to see if the category changes, and if so, write the 
-     new file out, and unlink the old one.  */
-  if (strcmp (field_value (pr, CATEGORY (database)),
-	      field_value (new_pr, CATEGORY (database))) != 0)
+  if (!pr_update (pr, new_pr, err))
     {
-      char *dirPath;
-
-      asprintf (&dirPath, "%s/%s", databaseDir (database), 
-		field_value (new_pr, CATEGORY (database)));
-
-      if (! fileExists (dirPath))
-	{
-	  if (createCategoryDirs (database))
-	    {
-	      mode_t mode = categoryDirPerms (database);
-
-	      if (mkdir (dirPath, mode) != 0)
-		{
-		  setError (err, CODE_FILE_ERROR, 
-			    "Error creating directory for category %s: %s",
-			    field_value (new_pr, CATEGORY (database)),
-			    strerror (errno));
-		  free (dirPath);
-		  return 0;
-		}
-	    }
-	  else
-	    {
-	      setError (err, CODE_FILE_ERROR, 
-			"Directory for category %s does not exist",
-			field_value (new_pr, CATEGORY (database)));
-	      free (dirPath);
-	      return 0;
-	    }
-	}
-      free (dirPath);
-    }
-
-  /* backup the current PR file */
-  old_path = gen_pr_path (pr);
-  asprintf (&bkup_path, "%s.old", old_path);
-  if (rename (old_path, bkup_path) < 0)
-    {
-      if (errno != EXDEV)
-	{
-	  setError (err, CODE_FILE_ERROR, "Could not rename %s: %s",
-		    old_path, strerror (errno));
-	  free (bkup_path);
-	  free (old_path);
-	  return 0;
-	}
-      if (copy_file (old_path, bkup_path) != 0)
-	{
-	  setError (err, CODE_FILE_ERROR, "Could not copy %s to %s: %s",
-		    old_path, bkup_path, strerror (errno));
-	  free (bkup_path);
-	  free (old_path);
-	  return 0;
-	}
-
-      /* Don't complain if this fails, since trying to write to it will give
-	 us the diagnostic if it's really serious.  */
-      unlink (old_path);
-    }
-
-  /* Now build the file.  */
-  new_path = gen_pr_path (new_pr);
-  prfile = fopen (new_path, "w+");
-  if (prfile == (FILE *) NULL)
-    {
-      setError (err, CODE_FILE_ERROR, "Cannot write the PR to %s: %s",
-		new_path, strerror (errno));
-      free (bkup_path);
-      free (old_path);
-      free (new_path);
       return 0;
     }
 
-  /* We had to wait until now because we wanted to wait and see
-     about changing the closed_date. XXX ??? !!! FIXME */
-
-  buildIndexEntry (new_pr);
-
-  write_entire_header (prfile, new_pr, "\n");
-  fprintf (prfile, "\n");
-  write_entire_pr (prfile, new_pr, "\n");
-
-  if (fclose (prfile) == EOF)
-    {
-      setError (err, CODE_FILE_ERROR, "Error writing out PR %s: %s",
-		new_path, strerror (errno));
-      free (bkup_path);
-      free (old_path);
-      free (new_path);
-      return 0;
-    }
-
-  unlink (bkup_path);
-
-  /* unlink the old file, if it is in another category dir. */
-  if (strcmp (field_value (pr, CATEGORY (database)),
-	      field_value (new_pr, CATEGORY (database))) != 0)
-    {
-      unlink (old_path);
-    }
-
-  free (bkup_path);
-  free (old_path);
-  free (new_path);
-
-  /* write out the new index.  */
-  replaceCurrentPRInIndex (pr, new_pr, err);
-  if (writeIndex (database, err) != 0)
-    {
-      res = 0;
-    }
-
   /* Send mail about the edit.  */
   if (newAuditTrailEntries != NULL)
     {
@@ -556,7 +399,7 @@ rewrite_pr (PR *pr, PR *new_pr, const char *editUserEmailAddr, ErrorDesc *err)
       newAuditTrailEntries = NULL;
     }
 
-  return res;
+  return 1;
 }
 
 
@@ -586,12 +429,12 @@ replace_pr (const DatabaseInfo database, FILE *fp,
       return 0;
     }
 
-  if (! prExists (database, prnum, err))
+  if (! pr_exists (database, prnum, err))
     {
       return 0;
     }
 
-  curr_pr = readPRWithNum (database, prnum, 0, err);
+  curr_pr = pr_load_by_id (database, prnum, 0, err);
   if (curr_pr == NULL)
     {
       setError (err, CODE_NO_INDEX,
@@ -685,7 +528,7 @@ validateFieldValue (FieldIndex field, const char *text, ErrorDesc *err,
 	    char *prnum = get_next_field (&tptr, ' ');
 	    if (prnum[0] != '\0')
 	      {
-		if (! prExists (fieldDefForIndex (field)->database, prnum,
+		if (! pr_exists (fieldDefForIndex (field)->database, prnum,
 				err))
 		  {
 		    setError (err, CODE_INVALID_FIELD_CONTENTS,
@@ -911,9 +754,9 @@ lock_pr (const DatabaseInfo database, const char *prID,
 
       FILE *fp = fopen (lock_path, "r");
 
-      /* If we couldn't open it for reading, something else is hosed,
-	 so just bail now.  */
-      if (fp == (FILE *) NULL)
+      /* If we couldn't open it for reading or get the lock file contents,
+	 something else is hosed, so just bail now. */
+      if (fp == (FILE *) NULL || fgets (buf, sizeof (buf) - 1, fp) == NULL)
 	{
 	  setError (err, CODE_FILE_ERROR, "Cannot read lock file %s",
 		    lock_path);
@@ -923,8 +766,6 @@ lock_pr (const DatabaseInfo database, const char *prID,
 	  return 0;
 	}
 
-      /* read the contents of the lock file */
-      fgets (buf, sizeof (buf) - 1, fp);
       s = strchr (buf, '\n');
       if (s != NULL)
 	{
@@ -994,7 +835,7 @@ edit_field (const DatabaseInfo database, const char *prnum,
   int res;
   PR *pr, *new_pr;
 
-  if (! prExists (database, prnum, err))
+  if (! pr_exists (database, prnum, err))
     {
       free (newcontents);
       if (changeReason != NULL)
@@ -1034,7 +875,7 @@ edit_field (const DatabaseInfo database, const char *prnum,
       return 0;
     }
 
-  pr = readPRWithNum (database, prnum, 0, err);
+  pr = pr_load_by_id (database, prnum, 0, err);
   if (pr == NULL)
     {
       unlock_pr (database, prnum, err);
@@ -1071,7 +912,7 @@ edit_field (const DatabaseInfo database, const char *prnum,
   set_field (new_pr, NUMBER (database), prnum, err);
   set_field (new_pr, CATEGORY (database), field_value (pr, CATEGORY (database)),
 	     err);
-  fillInPR (new_pr, err);
+  pr_load (new_pr, err);
 
   /* set_field () verifies that the value is valid before doing the
      set.  */
