@@ -1,6 +1,6 @@
 /* Main handling routines for GNATS.
    Copyright (C) 2001 Milan Zamazal
-   Copyright (C) 1993, 1994, 1995, 1999, 2000 Free Software Foundation, Inc.
+   Copyright (C) 1993, 1994, 1995, 1999, 2000, 2007 Free Software Foundation, Inc.
    Contributed by Tim Wicinski (wicinski@barn.com) and
    by Brendan Kehoe (brendan@cygnus.com).
    Further hacked by Milan Zamazal (pdm@zamazal.org).
@@ -9,7 +9,7 @@ This file is part of GNU GNATS.
 
 GNU GNATS is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU GNATS is distributed in the hope that it will be useful,
@@ -18,20 +18,21 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU GNATS; see the file COPYING.  If not, write to the Free
-Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
+along with GNU GNATS; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
+*/
 
 #include "gnats.h"
 #include "query.h"
 #include "pcodes.h"
 #include "mail.h"
+#include "ds.h"
 
 static int needs_analysis (PR *pr);
 
 static int run_atpr(PR *pr, AdmEntry *submitter, int submitter_rtime,
-		    struct tm *expired, char *bug_name, ErrorDesc *err);
+		    struct tm *expired, int bug_number, ErrorDesc *err);
 
-static int getBugNumber        (const DatabaseInfo database, ErrorDesc *err);
 static char* derive_submitter  (PR *pr);
 
 static int missing_required_fields (const DatabaseInfo database, PR *pr,
@@ -45,18 +46,13 @@ static int missing_required_fields (const DatabaseInfo database, PR *pr,
    should cause the category to be automatically created.  */
 
 static int
-createNewPRFile (PR *pr, int flag_autocreate, ErrorDesc *err)
+createNewPR (PR *pr, ErrorDesc *err)
 {
   const DatabaseInfo database = pr->database;
   int bug_number = 0;
-  int errnum = 0;
   AdmEntry *submitter = NULL;
   AdmEntry *category = NULL;
   AdmEntry *responsible = NULL;
-  char *path = NULL;
-  char *prPath = NULL;
-  char *bug_name = NULL;
-  char number[14]; /* No more than 13 digits in a PR #, ha ha.  */
   struct tm *expired = NULL;
   int submitter_rtime;
 
@@ -248,15 +244,6 @@ createNewPRFile (PR *pr, int flag_autocreate, ErrorDesc *err)
       }
   }
 
-  /* Set arrival date and time of response.  */
-  {
-    time_t seconds  = time ((time_t) 0);
-    char arrival_time[GNATS_TIME_LENGTH];
-    gnats_strftime (arrival_time, GNATS_TIME_LENGTH, "%a %b %d %H:%M:%S %z %Y",
-		    localtime (&seconds));
-    set_field (pr, ARRIVAL_DATE (database), arrival_time, err);
-  }
-
   /* If the submitter isn't supposed to have a response time, don't bother
      trying to get it.  */
   if (submitter_rtime >= 0)
@@ -264,58 +251,6 @@ createNewPRFile (PR *pr, int flag_autocreate, ErrorDesc *err)
       expired = get_response_time (database, submitter_rtime);
     }
 
-  /* Put together the path to where the bug will be stored.  If the dir
-     is not there, and the category is the default, auto-create that one,
-     if we want to.  If not, make the bug pending, and store in there.  */
-
-  asprintf (&path, "%s/%s", databaseDir (database), bug_group);
-
-  errnum = fileExists (path) ? 0 : -1;
-
-  if (errnum != 0 && ! flag_autocreate)
-    {
-      /* XXX ??? !!! Should append a message to the email being sent out. */
-      bug_group = defaultCategory(database);
-      set_field (pr, CATEGORY (database), defaultCategory(database), err);
-      log_msg (LOG_INFO, 1, "directory does not exist, changing to default:",
-	       path);
-      free (path);
-      asprintf (&path, "%s/%s", databaseDir (database), bug_group);
-      errnum = fileExists (path) ? 0 : -1;
-    }
-
-  /* Check ERR again, to see if default category was there.  */
-  if (errnum != 0)
-    {
-      mode_t mode = categoryDirPerms (database);
-
-      if (strcmp (bug_group, defaultCategory(database)) == 0)
-	{
-	  log_msg (LOG_INFO, 1, defaultCategory(database),
-		   " does not exist, creating...");
-	  if (mkdir (path, mode) != 0)
-	    {
-	      setError (err, CODE_FILE_ERROR,
-			"Can't create `%s' directory under %s.",
-			defaultCategory(database), databaseDir (database));
-	      return -1;
-	    }
-	}
-      else if (flag_autocreate)
-	{
-	  if (mkdir (path, mode) != 0)
-	    {
-	      setError (err, CODE_FILE_ERROR,
-			"Cannot create group: %s", path);
-	      return -1;
-	    }
-	  else
-	    {
-	      log_msg (LOG_INFO, 1, "creating directory:", path);
-	    }
-	}
-    }
-
   {
     /* Ensure the PR has a valid STATE.  We set the default state
        on any of these cases:
@@ -348,39 +283,12 @@ createNewPRFile (PR *pr, int flag_autocreate, ErrorDesc *err)
       }
   }
 
-  /* Retrieve a unique bug number.  */
-  bug_number = getBugNumber (database, err);
+  bug_number = pr_create (pr, err);
 
   if (bug_number > 0)
     {
-      sprintf (number, "%d", bug_number);
-      set_field (pr, NUMBER (database), number, err);
-
       bad_fields = checkEnumTypes (pr, bad_fields, 1);
  
-      /* Write the file out.  */
-      asprintf (&bug_name, "%s/%d", bug_group, bug_number);
-      asprintf (&prPath, "%s/%s", databaseDir (database), bug_name);
-      if (createPrFile (pr, prPath, 1, err) != 0)
-	{
-	  bug_number = -1;
-	}
-      else
-	{
-	  log_msg (LOG_INFO, 1, "PR written out:", prPath);
-
-	  /* Add a line into the index for use by query-pr.  */
-	  /* This should be done regardless of whether the bug is default or
-	     not. */
-	  if (addToIndex (pr, err) != 0)
-	    {
-	      bug_number = -1;
-	    }
-	}
-    }
-
-  if (bug_number > 0)
-    {
       /* If it isn't in the default category [pending], send all of
 	 the mail for it, create an index entry, and run at_pr.  Otherwise,
 	 just notify gnats-admin.  */
@@ -400,7 +308,7 @@ createNewPRFile (PR *pr, int flag_autocreate, ErrorDesc *err)
 	  if (submitter_rtime != -1 && notifyExpire (database)
 	      && needs_analysis (pr))
 	    {
-	      if (run_atpr (pr, submitter, submitter_rtime, expired, bug_name, 
+	      if (run_atpr (pr, submitter, submitter_rtime, expired, bug_number,
 			    err) != 0)
 		{
 		  bug_number = -1;
@@ -417,18 +325,6 @@ createNewPRFile (PR *pr, int flag_autocreate, ErrorDesc *err)
   free_adm_entry (category);
   free_adm_entry (submitter);
   free_adm_entry (responsible);
-  if (path != NULL)
-    {
-      free (path);
-    }
-  if (prPath != NULL)
-    {
-      free (prPath);
-    }
-  if (bug_name != NULL)
-    {
-      free (bug_name);
-    }
   if (def_subm != NULL)
     {
       free (def_subm);
@@ -532,7 +428,7 @@ arg_quote (const char *s)
 
 static int
 run_atpr (PR *pr, AdmEntry *submitter, int submitter_rtime, 
-	  struct tm *expired, char *bug_name, ErrorDesc *err)
+	  struct tm *expired, int bug_number, ErrorDesc *err)
 {
   char *at_pr;
   char *command = NULL;
@@ -570,9 +466,9 @@ run_atpr (PR *pr, AdmEntry *submitter, int submitter_rtime,
 	  char *cont = arg_quote (submitter->admFields[SubmitterAdmContact]);
 	  char *pa = arg_quote (gnatsAdminMailAddr (pr->database));
       
-	  fprintf (p, "%s --database %s %d %s %s '%s' '%s' '%s'\n", at_pr,
+	  fprintf (p, "%s --database %s %d %d %s '%s' '%s' '%s'\n", at_pr,
 		   databaseName (pr->database),
-		   submitter_rtime, bug_name,
+		   submitter_rtime, bug_number,
 		   submitter->admFields[SubmitterAdmKey],
 		   orig, cont, pa);
 
@@ -659,7 +555,7 @@ checkIfReply (PR *pr, ErrorDesc *err)
   free (regs.start);
   free (regs.end);
 
-  if (! prExists (pr->database, prID, err))
+  if (! pr_exists (pr->database, prID, err))
     {
       free (prID);
       prID = NULL;
@@ -787,7 +683,7 @@ append_report (FILE *infile, PR *new_pr, const char *number,
       date = get_curr_date ();
     }
 
-  if (! prExists (new_pr->database, number, err))
+  if (! pr_exists (new_pr->database, number, err))
     {
       return 1;
     }
@@ -827,7 +723,7 @@ Date: %s\n\
 
   fclose (infile);
 
-  pr = readPRWithNum (new_pr->database, number, 0, err);
+  pr = pr_load_by_id (new_pr->database, number, 0, err);
   if (pr == NULL)
     {
       return 1;
@@ -865,61 +761,6 @@ Date: %s\n\
   return 0;
 }
 
-/* Return the next available unique GNATS id.  */
-static int
-getBugNumber (const DatabaseInfo database, ErrorDesc *err)
-{
-  char *sbuf;
-  int bug_number;
-  FILE *bug_file;
-
-  /* First try to find and lock the gnats lock file.  We need this since
-     they want every bug to have a unique number.  If lock doesn't exist,
-     make it, if possible.  */
-  sbuf = gnats_adm_dir (database, "current");
-
-  block_signals ();
-
-  bug_file = fopen (sbuf, "r+");
-  if (bug_file == (FILE *) NULL)
-    {
-      log_msg (LOG_INFO, 1, "file 'current' not found, creating", sbuf);
-      bug_file = fopen (sbuf, "w+");
-      if (bug_file != (FILE *) NULL)
-	{
-	  bug_number = 1;
-	}
-      else
-	{
-	  setError (err, CODE_FILE_ERROR,
-		    "Can't create the GNATS 'current' file (%s).",
-		    sbuf);
-	  return -1;
-	}
-    }
-  else
-    {
-      if (fscanf (bug_file, "%d", &bug_number) != 1)
-	{
-	  setError (err, CODE_FILE_ERROR,
-		    "Can't read from the global PR number counter (%s).",
-		    sbuf);
-	  return -1;
-	}
-
-      bug_number++;      
-      rewind (bug_file);
-    }
-
-  fprintf (bug_file, "%d", bug_number);
-
-  fclose (bug_file);
-  unblock_signals ();
-  free (sbuf);
-
-  return bug_number;
-}
-
 /* Submit the PR whose contents are referred to by FP.
  * Return the new PR number if it's a new PR, or return the PR number of
  * the PR which was appended to if it's an existing PR. */
@@ -957,7 +798,7 @@ submit_pr (const DatabaseInfo database, FILE *fp, ErrorDesc *err)
       else
 	{
 	  read_pr (pr, fp, 0);
-	  retval = createNewPRFile (pr, createCategoryDirs (database), err);
+	  retval = createNewPR (pr, err);
 	  result = (retval < 0) ? 0 : retval;
 	}
     }
