@@ -1,5 +1,5 @@
 /* Define all procedures which are external to each other.
-   Copyright (C) 1993, 1995, 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1993,95,99,2000,01,02,07 Free Software Foundation, Inc.
    Contributed by Tim Wicinski (wicinski@barn.com).
    Hacked by Brendan Kehoe (brendan@cygnus.com).
    Further hacked by Milan Zamazal (pdm@zamazal.org).
@@ -8,7 +8,7 @@ This file is part of GNU GNATS.
 
 GNU GNATS is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU GNATS is distributed in the hope that it will be useful,
@@ -17,8 +17,9 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU GNATS; see the file COPYING.  If not, write to the Free
-Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
+along with GNU GNATS; see the file COPYING. If not, see
+<http://www.gnu.org/licenses/>.
+*/
 
 #ifndef _gnats_h_ 
 #define _gnats_h_ 
@@ -32,11 +33,19 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
 
 #include "config.h"
 
+/* fileno() is not standard C, and requires the POSIX feature test macro to
+   be defined on linux. Avoid the macro on FreeBSD, it breaks other stuff. */
+#if defined (__linux__) && !defined (__FreeBSD__)
+#define _POSIX_SOURCE 1
+#endif
 #include <stdio.h>
+
 #include <time.h>
+
 /* On FreeBSD this ends up defining RE_DUP_MAX.  We need to make sure it's
    included before our regex.h. */
 #include <sys/param.h>
+#include <limits.h>    /* for LONG_MAX */
 
 /* Use some miscelaneous functions; should be included after stdio.h */
 #include "ansidecl.h"
@@ -243,13 +252,19 @@ extern char *version_string;
 /* The name this program was run with. */
 extern const char *program_name;
 
+/* location of global databases list file */
+const char *global_db_list_file;
+
+/* default location of global databases list file */
+#ifndef GLOBAL_DB_LIST_FILE
+#define GLOBAL_DB_LIST_FILE "/etc/databases"
+#endif
 
 
 /* Local includes. */
 
 #include "field.h"
 #include "database.h"
-#include "index.h"
 #include "pr.h"
 #include "query.h"
 #include "regex.h"
