@@ -1,5 +1,5 @@
 /* Remote GNATS server.
-   Copyright (C) 1994, 95, 96, 1997, 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1994,95,96,97,99,2000,01,02,07 Free Software Foundation, Inc.
    Contributed by Brendan Kehoe (brendan@cygnus.com).
    Further hacked by Milan Zamazal (pdm@zamazal.org).
 
@@ -7,7 +7,7 @@ This file is part of GNU GNATS.
 
 GNU GNATS is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU GNATS is distributed in the hope that it will be useful,
@@ -16,8 +16,9 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU GNATS; see the file COPYING.  If not, write to the Free
-Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
+along with GNU GNATS; see the file COPYING. If not, see
+<http://www.gnu.org/licenses/>.
+*/
 
 #include "gnats.h"
 #include "gnatsd.h"
@@ -55,6 +56,7 @@ static Access_Level max_access_level = ACCESS_ADMIN;
 struct option long_options[] =
 {
   {"database", 1, NULL, 'd'},
+  {"global-databases-file", 1, NULL, 'g'},
   {"not-inetd", 0, NULL, 'n'},
   {"maximum-access-level", 1, NULL, 'm'},
   {"version", 0, NULL, 'V'},
@@ -70,12 +72,14 @@ Communication interface to GNATS databases.\n\
 \n",
   "\
   -d --database=DATABASE            use DATABASE\n\
+  -g --global-databases-file=PATH   PATH to databases file\n\
   -n --not-inetd                    no need to authorize when using Kerberos\n\
   -m --maximum-access-level=LEVEL   do not allow exceeding access LEVEL\n\
 \n\
   -h --help                         display this help and exit\n\
   -V --version                      output version information and exit\n",
-  NULL};
+  NULL
+};
 
 #ifdef HAVE_KERBEROS
 /* Non-zero if the client has used Kerberos authentication.  */
@@ -287,7 +291,7 @@ password_match (const char *password, const char *hash)
 
 /*  */
 static char *
-get_name (struct in_addr *host)
+get_name (struct in_addr *host, int type)
 {
   char *buf;
   int i;
@@ -296,7 +300,7 @@ get_name (struct in_addr *host)
   char **pp;
 #endif
 
-  hp = gethostbyaddr ((char *) host, sizeof (*host), AF_INET);
+  hp = gethostbyaddr ((char *) host, sizeof (*host), type);
   if (hp == NULL)
     {
       return NULL;
@@ -597,17 +601,16 @@ startConnection (void)
 #else
   int len;
 #endif
-  int access = ACCESS_UNKNOWN;
 
   len = sizeof (s);
   if (getpeername (0, (struct sockaddr *)&s, &len) < 0)
     {
       if (! isatty (0))
 	{
-	  log_msg (LOG_ERR, FALSE, "can't get peername %m", "?");
+	  syslog (LOG_ERR, "cannot get peername %m");
 	  printf ("%d Why can't I figure out your name?  Later.\r\n",
 		  CODE_NO_ACCESS);
-	  access = ACCESS_DENY;
+	  exit (1);
 	}
       else
 	{
@@ -617,18 +620,23 @@ startConnection (void)
     }
   else
     {
-      if (s.sin_family != AF_INET)
+      if ((s.sin_family != AF_INET)
+#if HAVE_DECL_AF_INET6 || defined(AF_INET6)
+	  /* AF_INET6 could be an enum or defined, if present */
+	  && (s.sin_family != AF_INET6)
+#endif
+	 )
 	{
 	  syslog (LOG_ERR, "%s: bad address family %ld",
 		  "?", (long) s.sin_family);
 	  printf ("%d You're a member of a bad address family.  Later.\r\n",
 		  CODE_NO_ACCESS);
-	  access = ACCESS_DENY;
+	  exit (1);
 	}
       else
 	{
 	  current_addr = (char *) inet_ntoa (s.sin_addr);
-	  current_host = get_name (&s.sin_addr);
+	  current_host = get_name (&s.sin_addr, s.sin_family);
 	  if (current_host == NULL)
 	    {
 	      current_host = current_addr;
@@ -956,7 +964,7 @@ main (int argc, char **argv)
 
   program_name = basename (argv[0]);
 
-  while ((optc = getopt_long (argc, argv, "d:nm:Vh",
+  while ((optc = getopt_long (argc, argv, "d:g:nm:Vh",
 			      long_options, (int *) 0)) != EOF)
     {
       switch (optc)
@@ -965,23 +973,32 @@ main (int argc, char **argv)
 	  database = optarg;
 	  break;
 
-	case 'n':
-	  not_inetd = 1;
+	case 'g':
+	  if (optarg[0] == '\0')
+	    {
+              fprintf(stderr, "%s: filename must be non-null\n", program_name);
+              exit(1);
+	    }
+	  global_db_list_file = optarg;
+	  break;
+
+	case 'h':
+	  usage (USAGE, 0);
 	  break;
 
 	case 'm':
           max_access_level = access_level(optarg);
 	  break;
 
+	case 'n':
+	  not_inetd = 1;
+	  break;
+
 	case 'V':
 	  version (PROGRAM_NAME);
 	  exit (0);
 	  break;
 
-	case 'h':
-	  usage (USAGE, 0);
-	  break;
-	  
 	default:
 	  usage (USAGE, 1);
 	}
