@@ -1,5 +1,5 @@
 /* Routines to provide lists of the GNATS low-level files.
-   Copyright (C) 1995, 1999, 2000 Free Software Foundation, Inc.
+   Copyright (C) 1995, 1999, 2000, 2007  Free Software Foundation, Inc.
    Contributed by Brendan Kehoe (brendan@cygnus.com).
    Majorly reworked by Bob Manson (manson@juniper.net).
 
@@ -7,7 +7,7 @@ This file is part of GNU GNATS.
 
 GNU GNATS is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU GNATS is distributed in the hope that it will be useful,
@@ -16,9 +16,9 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU GNATS; see the file COPYING.  If not, write to the Free
-the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA.  */
+along with GNU GNATS; see the file COPYING. If not, see
+<http://www.gnu.org/licenses/>.
+*/
 
 #include "gnats.h"
 #include "query.h"
