@@ -1,13 +1,13 @@
 #!/bin/sh
 # Program to send mail for GNATS.
-# Copyright (C) 1999 Free Software Foundation, Inc.
+# Copyright (C) 1999,2007 Free Software Foundation, Inc.
 # Contributed by Bob Manson (manson@juniper.net)
 #
 # This file is part of GNU GNATS.
 #
 # GNU GNATS is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2, or (at your option)
+# the Free Software Foundation; either version 3, or (at your option)
 # any later version.
 #
 # GNU GNATS is distributed in the hope that it will be useful,
@@ -16,13 +16,13 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with GNU GNATS; see the file COPYING.  If not, write to
-# the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+# along with GNU GNATS; see the file COPYING.  If not, see
+# <http://www.gnu.org/licenses/>.
 
 # This is a rather pointless script, but at least it isolates the number
 # of programs that actually invoke the mail agent to 1, making it easy
 # to change.
 
-MAIL_AGENT="xDEFAULT_MAIL_AGENTx"
+MAIL_AGENT="@DEFAULT_MAIL_AGENT@"
 
 exec $MAIL_AGENT $@ > /dev/null
