@@ -1,13 +1,13 @@
 #!/bin/sh
 # Program to process GNATS queries via email.
-# Copyright (C) 1993, 1994, 1995 Free Software Foundation, Inc.
+# Copyright (C) 1993,94,95,2007 Free Software Foundation, Inc.
 # Contributed by Jason Merrill (jason@cygnus.com).
 #
 # This file is part of GNU GNATS.
 #
 # GNU GNATS is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2, or (at your option)
+# the Free Software Foundation; either version 3, or (at your option)
 # any later version.
 #
 # GNU GNATS is distributed in the hope that it will be useful,
@@ -16,13 +16,12 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with GNU GNATS; see the file COPYING.  If not, write to
-# the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+# along with GNU GNATS; see the file COPYING.  If not, see
+# <http://www.gnu.org/licenses/>.
 
 GNATS_ADMIN_ADDR="`query-pr --responsible-address gnats-admin`"
-LIBEXECDIR=xLIBEXECDIRx
 
-PATH=xBINDIRx:/bin:/sbin:/usr/bin:/usr/ucb:/usr/bsd:/usr/sbin
+PATH="@pkglibexecdir@:@sbindir@:@bindir@:/bin:/usr/bin:${PATH}"
 export PATH
 
 # Don't expand globs for the arguments to query-pr.
@@ -103,6 +102,6 @@ __EOF__
   query-pr --help >> $mail 2>&1
 fi
 
-$LIBEXECDIR/gnats/mail-agent < $mail
+mail-agent < $mail
 
 [ $? -eq 0 ] && rm -f $mail
