@@ -1,5 +1,5 @@
 /* Miscellaneous utility routines for GNATS.
-   Copyright (C) 2000, 2001 Milan Zamazal
+   Copyright (C) 2000, 2001, 2007 Milan Zamazal
    Copyright (C) 1993, 1994, 1995 Free Software Foundation, Inc.
    Contributed by Tim Wicinski (wicinski@barn.com)
    and Brendan Kehoe (brendan@cygnus.com).
@@ -9,7 +9,7 @@ This file is part of GNU GNATS.
 
 GNU GNATS is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU GNATS is distributed in the hope that it will be useful,
@@ -18,8 +18,9 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU GNATS; see the file COPYING.  If not, write to the Free
-Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
+along with GNU GNATS; see the file COPYING. If not, see
+<http://www.gnu.org/licenses/>.
+*/
 
 #include "gnats.h"
 
@@ -944,3 +945,28 @@ basename (name)
   return (char *) base;
 }
 #endif /* HAVE_BASENAME */
+
+#ifndef HAVE_UNSETENV
+#define __environ	environ
+extern char **environ;
+
+void
+unsetenv (name)
+     const char *name;
+{
+  const size_t len = strlen (name);
+  char **ep;
+
+  for (ep = __environ; *ep; ++ep)
+    if (!strncmp (*ep, name, len) && (*ep)[len] == '=')
+      {
+	/* Found it.  Remove this pointer by moving later ones back.  */
+	char **dp = ep;
+	do
+	  dp[0] = dp[1];
+	while (*dp++);
+	/* Continue the loop in case NAME appears again.  */
+      }
+
+}
+#endif /* !HAVE_UNSETENV */
