@@ -1,6 +1,6 @@
 /* Functions for manipulating a PR.
    Copyright (C) 2001 Milan Zamazal
-   Copyright (C) 1993, 1994, 1995, 1999, 2000 Free Software Foundation, Inc.
+   Copyright (C) 1993, 1994, 1995, 1999, 2000, 2007 Free Software Foundation, Inc.
    Originally contributed by Tim Wicinski (wicinski@barn.com)
    and Brendan Kehoe (brendan@cygnus.com).
    Completely rewritten by Bob Manson (manson@juniper.net).
@@ -10,7 +10,7 @@ This file is part of GNU GNATS.
 
 GNU GNATS is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU GNATS is distributed in the hope that it will be useful,
@@ -19,11 +19,13 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU GNATS; see the file COPYING.  If not, write to the Free
-Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
+along with GNU GNATS; see the file COPYING. If not, see
+<http://www.gnu.org/licenses/>.
+*/
 
 #include "gnats.h"
 #include "pcodes.h"
+#include "ds.h"
 
 /* These will eventually be properly configurable.  */
 #define PR_FIELD_TAG_START		'>'
@@ -127,13 +129,20 @@ allocPR (const DatabaseInfo database)
   int field_num = get_num_fields (database);
 
   res->database = database;
-  allocIndex (res);
+  pr_init (res);  /* initialize the private ds info */
   res->private = (struct PR_private *) xmalloc (sizeof (struct PR_private));
-  res->private->value
-    = (struct PR_private_value *) xmalloc (sizeof (struct PR_private_value)
-					   * field_num);
-  memset (res->private->value, 0,
-	  sizeof (struct PR_private_value) * field_num);
+  if (field_num == -1)
+    {
+      res->private->value = NULL;
+    }
+  else
+  {
+      res->private->value
+	= (struct PR_private_value *) xmalloc (sizeof (struct PR_private_value)
+					       * field_num);
+      memset (res->private->value, 0,
+	      sizeof (struct PR_private_value) * field_num);
+  }
   res->private->header 
     = (char **) xmalloc (sizeof (char *) * NUM_HEADER_ITEMS);
   memset (res->private->header, 0, sizeof (char *) * NUM_HEADER_ITEMS);
@@ -153,90 +162,6 @@ allocPR (const DatabaseInfo database)
   return res;
 }
 
-/* Get the PR at PATH.  PR is the PR entry to be filled in.
-   If PRUNE is non-zero, don't read any multitext fields.  */
-static int
-get_pr (PR *pr, const char *path, int prune)
-{
-  FILE *fp = fopen (path, "r");
-
-  if (fp == (FILE *)NULL)
-    {
-      return 0;
-    }
-
-  if (read_header (pr, fp) < 0)
-    {
-      return 0;
-    }
-
-  read_pr (pr, fp, prune);
-
-  fclose (fp);
-
-  return 1;
-}
-
-int
-fillInPR (PR *pr, ErrorDesc *err)
-{
-  char *path = gen_pr_path (pr);
-  const char *num = field_value (pr, NUMBER (pr->database));
-  int val;
-
-  if (num == NULL || path == NULL)
-    {
-      setError (err, CODE_ERROR, "Invalid PR in fillInPR()");
-      if (path != NULL)
-	{
-	  free (path);
-	}
-      return -1;
-    }
-  else
-    {
-      val = get_pr (pr, path, 0);
-
-      free (path);
-      if (val == 0)
-	{
-	  setError (err, CODE_FILE_ERROR, "Unable to read PR %s", num);
-	  return -1;
-	}
-      else
-	{
-	  return 0;
-	}
-    }
-}
-
-static PR *
-get_pr_from_index (const DatabaseInfo database, const char *prnum,
-		   ErrorDesc *err)
-{
-  PR *pr = getFirstPR (database, err);
-
-  /* If they gave it to us with the category, remove it. */
-  if (( strrchr (prnum, '/')) != NULL)
-    {
-      prnum = strrchr (prnum, '/') + 1;
-    }
-
-  while (pr != NULL && strcmp (prnum, field_value (pr, NUMBER (database))) != 0)
-    {
-      pr = getNextPR (pr);
-    }
-
-  if (pr == NULL)
-    {
-      setError (err, CODE_NONEXISTENT_PR,
-	        "No PR %s listed in the index.", prnum);
-      return NULL;
-    }
-
-  return pr;
-}
-
 /* Initializes PR for reading.  Each line of the PR should be passed
    in via addLineToPR (). */
 
@@ -906,8 +831,8 @@ setFieldChangeReason (PR *pr, FieldIndex field,
   
 
 /* Returns the value of field FIELD from PR.  If the PR does not directly
-   have a value, check the PR's associated index entry; if that's also
-   empty, we return the field's default value.  
+   have a value, check the field cache; if that's also empty, we return
+   the field's default value.  
 
    The policy about returning a default value is a bit broken--we
    should only do that if the PR's actually been read in from a file.  */
@@ -929,10 +854,7 @@ field_value (PR *pr, FieldIndex field)
   
   if (result == NULL)
     {
-      /* Houston, we have a problem.  For dates, the value that's
-	 stored in the index is an integer, not the actual value of
-	 the field...  \hbadness 10000.  XXX ??? !!! FIXME */
-      result = indexValue (pr, field);
+      result = field_cache_value (pr, field);
       if (result != NULL
 	  && fieldDefForIndex (field)->datatype == Date
 	  && strcmp (result, "0") == 0)
@@ -1365,143 +1287,13 @@ free_pr (PR *pr)
 {
   free_pr_header (pr);
   free_pr_contents (pr);
-  freePRIndex (pr);
-  free (pr->index);
+  pr_destroy (pr); /* free up the private ds info */
   free (pr->private->header);
   free (pr->private->value);
   free (pr->private);
   free (pr);
 }
 
-static char *
-get_pr_path (const DatabaseInfo database, PR *pr, const char *prnum,
-	    ErrorDesc *err)
-{
-  char *path = NULL;
-  const char *category = NULL;
-  char *categoryFromIndex = NULL;
-
-  if (pr != NULL)
-    {
-      category = field_value (pr, CATEGORY (database));
-    }
-  else
-    {
-      categoryFromIndex = getCategoryFromIndex (database, prnum, err);
-      category = categoryFromIndex;
-    }
-
-  if (category != NULL)
-    {
-      asprintf (&path, "%s/%s/%s", databaseDir (database), category, prnum);
-      if (categoryFromIndex != NULL)
-	{
-	  free (categoryFromIndex);
-	}
-    }
-
-  return path;
-}
-
-int
-prExists (const DatabaseInfo database, const char *prnum, ErrorDesc *err)
-{
-  PR *pr = get_pr_from_index (database, prnum, err);
-  char *path = get_pr_path (database, pr, prnum, err);
-  int res = 0;
-  if (path != NULL)
-    {
-      res = fileExists (path);
-      free (path);
-      if (res == 0)
-	{
-	  setError (err, CODE_FILE_ERROR, "Can't open file `%s'", path);
-	}
-    }
-  return res;
-}
-
-static bool
-pr_file_readable (const char *path, ErrorDesc *err)
-{
-  FILE *fp;
-
-  if (path == NULL)
-    {
-      return FALSE;
-    }
-
-  if ((fp = fopen (path, "r")) == NULL)
-    {
-      setError (err, CODE_FILE_ERROR, "Can't open file `%s'", path);
-      return FALSE;
-    }
-
-  fclose (fp);
-  return TRUE;
-}
-
-PR *
-readPRWithNum (const DatabaseInfo database, const char *prnum,
-	       int prune, ErrorDesc *err)
-{
-  PR *pr = NULL;
-  PR *index_pr = get_pr_from_index (database, prnum, err);
-  char *path = get_pr_path (database, index_pr, prnum, err);
-
-  if (path != NULL)
-    {
-      if (pr_file_readable (path, err))
-        {
-	  pr = allocPR (database);
-	  setPrevPR (pr, getPrevPR (index_pr));
-	  setNextPR (pr, getNextPR (index_pr));
-	  if (get_pr (pr, path, prune) == 0)
-	    {
-	      free_pr (pr);
-	      pr = NULL;
-	    }
-        }
-      free (path);
-    }
-  return pr;
-}
-
-int
-pr_delete (const DatabaseInfo database, const char *prnum, ErrorDesc *err)
-{
-  PR *pr;
-  char *path = NULL;
-
-  pr = get_pr_from_index (database, prnum, err);
-  path = get_pr_path (database, pr, prnum, err);
-
-  if (path == NULL || !pr_file_readable (path, err))
-    {
-      if (path != NULL)
-	{
-	  free (path);
-	}
-      return -1;
-    }
-
-  if (removePRFromIndex (database, prnum, err))
-    {
-      free (path);
-      return -5;
-    }
-  
-  if (unlink (path))
-    {
-      setError (err, CODE_FILE_ERROR, "Unable to unlink file %s\n", path);
-      free (path);
-      return -6;
-    }
-
-  free (path);
-  return 1;
-}
-
 void
 freeInputTemplate (InputTemplate *template)
 {
