@@ -1,12 +1,12 @@
 /* Pieces of the actual PR.
-   Copyright (C) 1993 Free Software Foundation, Inc.
+   Copyright (C) 1993,2007 Free Software Foundation, Inc.
    Contributed by Tim Wicinski (wicinski@barn.com).
 
 This file is part of GNU GNATS.
 
 GNU GNATS is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU GNATS is distributed in the hope that it will be useful,
@@ -15,8 +15,9 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU GNATS; see the file COPYING.  If not, write to the Free
-Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
+along with GNU GNATS; see the file COPYING. If not, see
+<http://www.gnu.org/licenses/>.
+*/
 
 #ifndef _pr_h_
 #define _pr_h_
@@ -52,15 +53,15 @@ typedef enum {
 #include <stdio.h>
 #include "gnats.h"
 #include "field.h"
-#include "index.h"
+#include "database.h"
 
 /* Describes one entire PR.  */
 struct PR_struct {
   /* The database this PR is associated with.  */
   DatabaseInfo database;
 
-  /* Index entry for this PR. */
-  Index *index;
+  /* all the datastore specific stuff */
+  void *ds_private;
 
   /* Non-zero if the PR contents are pruned.  */
   int prune;
@@ -88,7 +89,6 @@ extern int setBuiltinField (FieldIndex field, const char *builtinName);
 extern FieldIndex findBuiltinField (const DatabaseInfo database,
 				    const char *name);
 
-extern int fillInPR (PR *pr, ErrorDesc *err);
 extern void initReadPR (PR *pr);
 extern void addLineToPR (PR *pr, char *buffer, char *line, size_t linelen,
 			 int prune);
@@ -131,17 +131,8 @@ extern int fconfigParse (DatabaseInfo database, const char *filename,
 extern int createPrFile (PR *pr, const char *filename, int force,
 			 ErrorDesc *err);
 
-extern int pr_delete (const DatabaseInfo database, const char *prnum,
-		      ErrorDesc *err);
-
-extern int prExists (const DatabaseInfo database, const char *prID, 
-		     ErrorDesc *err);
-
 extern void printValidValues (FILE *outfile, FieldIndex i, const char *eol);
 
-extern PR *readPRWithNum (const DatabaseInfo database, const char *prID,
-			  int prune, ErrorDesc *err);
-
 /* Given the name of a header NAME, return its Header_Name value, or
    InvalidHeaderName if NAME is not a valid header name.  */
 extern Header_Name find_header_index (const char *name);
