@@ -1,6 +1,6 @@
 /* Perform queries on the contents of a GNATS database.
    Copyright (C) 2001, 2002 Milan Zamazal
-   Copyright (C) 1993, 94, 95, 96, 1997, 2000 Free Software Foundation, Inc.
+   Copyright (C) 1993, 94, 95, 96, 1997, 2000, 07 Free Software Foundation, Inc.
    Contributed by Brendan Kehoe (brendan@cygnus.com).
    Further hacked by Milan Zamazal (pdm@zamazal.org).
 
@@ -8,7 +8,7 @@ This file is part of GNU GNATS.
 
 GNU GNATS is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU GNATS is distributed in the hope that it will be useful,
@@ -17,12 +17,14 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU GNATS; see the file COPYING.  If not, write to the Free
-Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
+along with GNU GNATS; see the file COPYING. If not, see
+<http://www.gnu.org/licenses/>.
+*/
 
 #include "gnats.h"
 #include "query.h"
 #include "mail.h"
+#include "ds.h"
 
 /* The name this program was run with.  */
 const char *program_name;
@@ -55,6 +57,7 @@ struct option long_options[] =
   {"database", 1, NULL, 'd'},
   {"format", 1, NULL, 'f'},
   {"full", 0, NULL, 'F'},
+  {"global-databases-file",1,NULL,'g'},
   {"help", 0, NULL, 'h'},
   {"host", 1, NULL, 'H'},
   {"port", 1, NULL, PORT_OPTION},
@@ -127,6 +130,7 @@ Query database.\n\
   "Options:\n\
           [--output file | -o file]\n\
           [--database database | -d database]\n\
+          [--global-databases-file PATH | -g PATH ]\n\
           [--responsible-address address]\n\
           [--list-databases] [--list-fields] [--list-input-fields]\n\
           [--field-type type] [--field-description description]\n\
@@ -354,7 +358,7 @@ main (int argc, char **argv)
   char *hostname = NULL;
   int port = -1;
   int is_network_client = 0;
-  static const char *optstring = "a:A:b:B:c:C:Dd:e:f:K:L:m:M:n:o:O:p:PQ:s:S:r:t:u:U:v:w:y:z:Z:VFGiIxhqH:RjJklT|&";
+  static const char *optstring = "a:A:b:B:c:C:Dd:e:f:g:K:L:m:M:n:o:O:p:PQ:s:S:r:t:u:U:v:w:y:z:Z:VFGiIxhqH:RjJklT|&";
   /* If 1, don't allow redirection or viewing of confidential PRs.  */
   int restricted = 0;
   ListTypes whichList = 0;
@@ -415,6 +419,15 @@ main (int argc, char **argv)
 	  formats++;
 	  break;
 
+	case 'g':
+	  if (optarg[0] == '\0')
+	    {
+              fprintf(stderr, "%s: filename must be non-null\n", program_name);
+              exit(1);
+	    }
+	  global_db_list_file = optarg;
+	  break;
+
 	case 'o':
 	  if (strcmp (optarg, "-") && !restricted)
 	    outfile_name = optarg;
@@ -960,8 +973,8 @@ main (int argc, char **argv)
       {
 	ErrorDesc err;
 
-	int res = iterate_prs (database, argc - optind, argv + optind, expr,
-			       query_format, client_print_query, &err);
+	int res = db_query (database, argc - optind, argv + optind, expr,
+			   client_print_query, query_format, &err);
 	if (res < 0)
 	  {
 	    client_print_errors (database, err);
