@@ -1,5 +1,5 @@
 /* Query handling code.
-   Copyright (C) 1994, 95, 96, 1997, 1999, 2000 Free Software Foundation, Inc.
+   Copyright (C) 1994, 95, 96, 97, 99, 2000, 07 Free Software Foundation, Inc.
    Contributed by Brendan Kehoe (brendan@cygnus.com).
    Massively revised by Bob Manson (manson@juniper.net).
 
@@ -7,7 +7,7 @@ This file is part of GNU GNATS.
 
 GNU GNATS is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU GNATS is distributed in the hope that it will be useful,
@@ -16,21 +16,17 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU GNATS; see the file COPYING.  If not, write to the Free
-Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
+along with GNU GNATS; see the file COPYING. If not, see
+<http://www.gnu.org/licenses/>.
+*/
 
 #include "gnats.h"
 #include "query.h"
 #include "pcodes.h"
+#include "ds.h"
 
 /* One item to search for. */
 
-typedef struct query_item
-{
-  ComplexFieldIndex fieldIndex;
-  struct re_pattern_buffer *compRegexp;
-} *QueryItem;
-
 static QueryItem freeQueryItemEnt = NULL;
 
 static QueryItem
@@ -86,37 +82,6 @@ freeQueryItem (QueryItem i)
     }
 }
 
-typedef struct search_item
-{
-  /* The type of search to perform, of course.  */
-  SearchType searchType;
-
-  /* The items on the left and right-hand-sides. */
-  QueryItem lhs;
-  QueryItem rhs;
-} SearchItem;
-
-typedef struct queryTree
-{
-  /* The operation to perform on this node. */
-  QueryOp op;
-
-  /* The left and right sides of the expression; if this is a unary op,
-     the left side contains the expression. */
-  struct queryTree *left, *right;
-
-  /* If this is a QueryMatch expression, the actual query to perform. */
-  SearchItem ent;
-} *QueryTree;
-
-struct queryExpr
-{
-  /* Database that this query is associated with.  */
-  DatabaseInfo database;
-  /* The actual query tree.  */
-  QueryTree tree;
-};
-
 struct SearchTypes {
   const char *name;
   const char *operator;
@@ -618,15 +583,6 @@ fieldCompare (PR *pr, PR *oldPR, QueryItem *fields,
 	  searchType = RegCmp;
 	}
     }
-  if ((! PR_IS_FULL (pr)) && (! isIndexedField (fields[0]->fieldIndex)))
-    {
-      ErrorDesc err;
-
-      if (fillInPR (pr, &err) != 0)
-	{
-	  return 0;
-	}
-    }
 
   for (x = 0; x < 2; x++)
     {
@@ -721,7 +677,7 @@ pr_match_field (PR *pr, PR *oldPR, SearchItem *item,
 /* Returns a non-zero value if the PR referenced by I matches the expression
    tree in QEXP.  */
 
-static int
+int
 pr_matches_tree (PR *pr, PR *oldPR, QueryTree qexp,
 		 FormatNamedParameter *params)
 {
@@ -1202,41 +1158,12 @@ int
 process_format (FILE *fp, char **res, PR *pr,  PR *oldPR, QueryFormat *fmt, 
 		const char *eolTerminator, FormatNamedParameter *parameters)
 {
-  int do_open_pr = 0;
-
   if (pr != NULL)
     {
-      if (! PR_IS_FULL (pr))
-	{
-	  FieldList p = fmt->fields;
-
-	  if (p == NULL)
-	    {
-	      do_open_pr = 1;
-	    }
-	  else
-	    {
-	      while (p != NULL)
-		{
-		  if (! isIndexedField (p->ent))
-		    {
-		      do_open_pr = 1;
-		      break;
-		    }
-		  p = p->next;
-		}
-	    }
-	}
-
-      if (do_open_pr)
-	{
-	  ErrorDesc err;
-
-	  if (fillInPR (pr, &err))
-	    {
-	      return 0;
-	    }
-	}
+      if (pr_load_fields (pr, fmt->fields) == -1)
+        {
+	  return 0;
+        }
     }
 
   if (fmt->printf != NULL)
@@ -1250,7 +1177,7 @@ process_format (FILE *fp, char **res, PR *pr,  PR *oldPR, QueryFormat *fmt,
       if (fmt->fields == NULL)
 	{
 	  write_entire_header (fp, pr, eolTerminator);
-	  fprintf (fp, eolTerminator);
+	  fprintf (fp, "%s", eolTerminator);
 	  writeFullPR (fp, pr, fmt->rawQuery, eolTerminator);
 	}
       else
@@ -1322,119 +1249,6 @@ print_pr (FILE *dest, PR *pr, QueryFormat *query_format,
 }
 
 
-/* Iterate through a set of PRs.  For those PRs that match the
-   expression in EXP, invoke FUNC with the count of PRs that have
-   matched so far, the PR* entry for the PR, and the supplied
-   QUERY_FORMAT.  
-
-   FUNC is invoked once more after all of the queries have been
-   searched.  The PR* pointer is NULL, and the count corresponds to
-   the total # of PRs that matched.
-
-   If AC is 0 or AV is NULL, we iterate through all of the PRs in the
-   index for the current database.  Otherwise, only those PRs that
-   match the PRIDs in AV[0], AV[1]. AV[2]...AV[AC-1] are tested.  */
-
-int
-iterate_prs (const DatabaseInfo database, int ac, char **av, QueryExpr exp,
-	     QueryFormat *query_format, QueryFunc func, ErrorDesc *err)
-{
-  int found = 0;
-  QueryTree tree = NULL;
-
-  if (exp != NULL)
-    {
-      if (exp->database != database)
-	{
-	  abort ();
-	}
-      tree = exp->tree;
-    }
-  
-  *err = NULL;
-  if (ac == 0 || av == NULL)
-    {
-      PR *pr = getFirstPR (database, err);
-
-      if (*err != NULL)
-	{
-	  return -1;
-	}
-      /* We weren't given a list of PRs to check, so we do the
-	 whole shooting match.  */
-      while (pr != NULL)
-	{
-	  if (pr_matches_tree (pr, NULL, tree, NULL))
-	    {
-	      found++;
-	      func (found, pr, query_format);
-	    }
-	  free_pr_header (pr);
-	  free_pr_contents (pr);
-	  pr = getNextPR (pr);
-	}
-    }
-  else
-    {
-      int cpr;
-
-      for (cpr = 0; cpr < ac; cpr++)
-	{
-	  char *pat, *n;
-	  char *p = av[cpr];
-	  int plen;
-	  PR *pr;
-	  struct re_pattern_buffer buf;
-
-	  memset (&buf, 0, sizeof (buf));
-
-	  /* Remove the category */
-	  if ((n = (char *) strrchr (p, '/')) != NULL) 
-	    {
-	      p = n + 1;
-	    }
-
-	  plen = strlen (p);
-	  pat = (char *) xmalloc (plen + 3);
-	  strcpy (pat, p);
-	  strcpy (pat + plen, "\\'");
-
-	  *err = NULL;
-	  pr = getFirstPR (database, err);
-	  if (*err != NULL)
-	    {
-	      return -1;
-	    }
-
-	  while (pr != NULL)
-	    {
-	      if (gnats_regcmp (pat, field_value (pr, NUMBER (pr->database)),
-				&buf) == 0)
-		{
-		  if (pr_matches_expr (pr, NULL, exp, NULL))
-		    {
-		      found++;
-		      func (found, pr, query_format);
-		    }
-		  /* Only one PR will match this PR number, because it's
-		     not really a regexp */
-		  break;
-		}
-	      free_pr_header (pr);
-	      free_pr_contents (pr);
-	      pr = getNextPR (pr);
-	    }
-	  buf.translate = NULL;
-	  regfree (&buf);
-	  free (pat);
-	}
-    }
-
-  func (found, NULL, 0);
-
-  return found;
-}
-
 static QueryTree
 newQueryTree (void)
 {
@@ -1615,11 +1429,11 @@ findMatchingQuote (const char *expr, const char *exprend)
 static void
 stripWhiteSpace (const char **expr, const char **expend)
 {
-  while (expr <= expend && isspace ((int)(unsigned char) **expr))
+  while (*expr <= *expend && isspace ((int) **expr))
     {
       (*expr)++;
     }
-  while (expr <= expend && isspace ((int)(unsigned char) **expend))
+  while (*expr <= *expend && isspace ((int) **expend))
     {
       (*expend)--;
     }
@@ -1706,7 +1520,7 @@ parseSimpleQueryExpression (const DatabaseInfo database, const char *expr,
 	}
       else 
 	{
-	  size_t len;
+	  size_t len = 0;
 	  SearchType searchType = getSearchTypeForOperator (expr, &len);
 
 	  if (searchType != InvalidSearchType)
