@@ -1,5 +1,5 @@
 /* Handle getting a message from email into GNATS.
-   Copyright (C) 2001 Free Software Foundation
+   Copyright (C) 2001, 07 Free Software Foundation
    Copyright (C) 1993, 1994, 1995 (FIXME: Brendan Kehoe or Cygnus/Red Hat)
    Contributed by Brendan Kehoe (brendan@cygnus.com).
    Further work by Milan Zamazal (pdm@zamazal.org) and Dirk Bergstrom
@@ -9,7 +9,7 @@ This file is part of GNU GNATS.
 
 GNU GNATS is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU GNATS is distributed in the hope that it will be useful,
@@ -18,17 +18,19 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU GNATS; see the file COPYING.  If not, write to the Free
-Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
-
-#include <limits.h>
-#include <sys/wait.h> /* FIXME */
-#include <sys/param.h> /* FIXME: gets MAXBSIZE */
+along with GNU GNATS; see the file COPYING. If not, see
+<http://www.gnu.org/licenses/>.
+*/
 
 #include "gnats.h"
 #include "gnats-dirs.h"
 
-#ifndef MAXBSIZE /* FIXME - from params.h */
+/* Put sys/wait.h (for waitpid, WEXITSTATUS) after gnats.h to avoid signal.h
+   syntax error about stack_t when compiling with gcc -ansi on solaris 10.  */
+#include <sys/wait.h> /* FIXME */ 
+#include <sys/param.h> /* FIXME: gets MAXBSIZE */
+
+#ifndef MAXBSIZE /* FIXME - from sys/param.h */
 #define MAXBSIZE 8192
 #endif
 
@@ -51,9 +53,10 @@ bool flag_debug = FALSE;
    queue for GNATS. */
 char *queue_file = NULL;
 
-struct option const long_options[] =
+struct option long_options[] =
 {
   {"database", 1, NULL, 'd'},
+  {"global-databases-file", 1, NULL, 'g'},
   {"file", 1, NULL, 'f'},
   {"debug", 0, NULL, 'D'},
   {"queue", 0, NULL, 'q'},
@@ -68,14 +71,15 @@ struct option const long_options[] =
 
 static const char *const USAGE[] = {
   "Usage: " PROGRAM_NAME " [OPTION]...\n\
-Handle messages submitted via e-mail.\n\
-",
+Handle messages submitted via e-mail.\n",
 "\n\
   -q, --queue               queue the given message\n\
   -r, --run                 process messages in the queue\n\
   -f, --file=FILENAME       read the message from FILENAME instead of stdin\n\
-  -m, --max-size=KBYTES     don't process messages larger than KBYTES\n\
+  -m, --max-size=KBYTES     don't process messages larger than KBYTES",
+"\n\
   -d, --database=DATABASE   use DATABASE instead of the default database\n\
+  -g, --global-databases-file=PATH   PATH to databases file\n\
   -D, --debug               enable some debugging\n\
   -h, --help                display this help and exit\n\
   -V, --version             display version information and exit\n\
@@ -85,6 +89,7 @@ Usually you want to specify exactly one of the options `--queue' and `--run'.\
 \n",
   NULL};
 
+
 /* Run pr-edit on FILENAME and return its exit status. */
 static int
 fork_gnats (DatabaseInfo database, const char *filename)
@@ -399,7 +404,7 @@ main (int argc, char **argv)
 
   /* FIXME: handle signals */
 
-  while ((optc = getopt_long (argc, argv, "d:f:VmqrDh",
+  while ((optc = getopt_long (argc, argv, "d:f:g:VmqrDh",
 			      long_options, (int *) 0)) != EOF)
     {
       switch (optc)
@@ -420,6 +425,15 @@ main (int argc, char **argv)
 	  queue_file = optarg;
 	  break;
 
+	case 'g':
+	  if (optarg[0] == '\0')
+	    {
+	      punt(database, 1, "filename must be non-null\n");
+       	    }
+	  global_db_list_file = optarg;
+	  break;
+
+
 	case 'r':
 	  if (queue_msg)
 	    {
@@ -466,8 +480,7 @@ main (int argc, char **argv)
 	  break;
 
 	default:
-	  fprintf (stderr, "%s", USAGE);
-	  exit (1);
+	  usage (USAGE, 1);
 	  break;
 	}
     }
