@@ -1,11 +1,11 @@
 /* Definitions for data structures and routines for the regular
    expression library, version 0.12.
 
-   Copyright (C) 1985,89,90,91,92,93,95,2000 Free Software Foundation, Inc.
+   Copyright (C) 1985,89,90,91,92,93,95,2000,07 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -14,9 +14,9 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
-   USA.  */
+   along with GNU GNATS; see the file COPYING. If not, see
+   <http://www.gnu.org/licenses/>.
+*/
 
 #ifndef _REGEX_H
 #define _REGEX_H 1
